# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`nextcloud`](#nextcloud): Install and manage Nextcloud

#### Private Classes

* `nextcloud::apps`: Manage Nextcloud apps
* `nextcloud::config`: Set configuration options for Nextcloud
* `nextcloud::cron`: Configure background cron jobs for Nextcloud
* `nextcloud::install`: Download and extract the distribution archive
* `nextcloud::pre_install`: Pre installation tasks
* `nextcloud::update`: Perform required tasks to update Nextcloud

### Defined types

* [`nextcloud::app_command`](#nextcloudapp_command): Run a command for a Nextcloud app
* [`nextcloud::config_command`](#nextcloudconfig_command): Set or remove a single configuration value
* [`nextcloud::install::distribution`](#nextcloudinstalldistribution): Download and extract the distribution archive

## Classes

### `nextcloud`

Install and manage Nextcloud

#### Parameters

The following parameters are available in the `nextcloud` class.

##### `admin_password`

Data type: `String`

Specifies the initial password for the Nextcloud admin user.

##### `admin_user`

Data type: `String`

Specifies the username for the Nextcloud admin.

##### `apps`

Data type: `Hash`

Specifies a list of Nextcloud apps and their desired state.

##### `command_timeout`

Data type: `Integer`

Specifies the time to wait for install/update/maintenance commands
to complete. Keep in mind that several commands may take a few hours
to complete, depending on the size of your installation.

##### `config`

Data type: `Hash`

A hash containing configuration options for Nextcloud.

##### `cronjobs`

Data type: `Hash`

Specifies a list of cron jobs that should be added when
`$manage_cron` is enabled.

##### `datadir`

Data type: `Stdlib::Compat::Absolute_path`

Specifies the directory where Nextcloud will store user data.
It MUST reside outside of Nextcloud's installation directory.

##### `datastatefile`

Data type: `Stdlib::Compat::Absolute_path`

A file that is required by the module to work properly. This value MUST NOT
be changed, because the path is hardcoded in several places.

##### `debug`

Data type: `Boolean`

Whether to enable additional output for debugging purposes.

##### `install_enabled`

Data type: `Boolean`

Whether to download and extract the release distribution files, switch the
symlink to the specified release. On new installs it also runs the required
PHP commands to install Nextcloud. When disabled these commands need to be
run manually and some features may not work as expected (not recommended).

##### `installroot`

Data type: `Stdlib::Compat::Absolute_path`

Specifies the base directory where Nextcloud should be installed. A new
subdirectory for each version will be created.

##### `manage_apps`

Data type: `Boolean`

Whether to manage Nextcloud apps. They can be installed, removed, enabled
or disabled.

##### `manage_cron`

Data type: `Boolean`

Whether to manage Nextcloud's background cron job(s).

##### `manage_php`

Data type: `Boolean`

Whether to setup and maintain PHP (FPM/CLI) and install modules needed
for Nextcloud.

##### `manage_redis`

Data type: `Boolean`

Whether to setup and maintain a local Redis server.

##### `manage_symlink`

Data type: `Boolean`

Whether to maintain a symlink for the current version of Nextcloud.
This must be enabled for the module to work as expected.

##### `mirror`

Data type: `Variant[Stdlib::HTTPUrl,Stdlib::HTTPSUrl]`

Specifies the base URL where the distribution archive can be downloaded.

##### `path`

Data type: `String`

Specifies the content of the PATH environment variable when running commands.

##### `php_extensions`

Data type: `Hash`

Specifies a list of PHP extensions that should be installed when
`$manage_php` is enabled.

##### `statefile`

Data type: `Stdlib::Compat::Absolute_path`

A file that is required by the module to work properly. This value MUST NOT
be changed, because the path is hardcoded in several places.

##### `symlink_name`

Data type: `String`

Specifies the name of the symlink. This is considered to represent
Nextcloud's home directory. It should be used as DocumentRoot and MUST NOT
be changed after completing the Nextcloud installation.

##### `system_group`

Data type: `String`

Specifies the name of the group that is used by the webserver and/or PHP FPM.
It will be used to set proper file permission for Nextcloud.

##### `system_user`

Data type: `String`

Specifies the name of the user that is used by the webserver and/or PHP FPM.
It will be used as owner for the Nextcloud installation files and it will be
used to run optional commands.

##### `update_enabled`

Data type: `Variant[Boolean, Enum['none']]`

Whether to run the required PHP commands to update Nextcloud. When disabled,
these commands need to be run manually and some features may not work as
expected. Note that this does NOT prevent the module from switching the
installation directory to a newer version, it just skips the execution of
Nextcloud's update commands. To completely disable all updates, the parameter
should be set to `none` (not recommended).

##### `version`

Data type: `String`

Specifies the version of Nextcloud that should be installed.

##### `db_driver`

Data type: `String`



##### `db_host`

Data type: `String`



##### `db_name`

Data type: `String`



##### `db_password`

Data type: `String`



##### `db_user`

Data type: `String`



## Defined types

### `nextcloud::app_command`

Run a command for a Nextcloud app

#### Parameters

The following parameters are available in the `nextcloud::app_command` defined type.

##### `app`

Data type: `String`

The name of the app.

Default value: `$title`

##### `command`

Data type: `Enum['install','remove','enable','disable','install_disable','post_update']`

The app command that should be executed.

### `nextcloud::config_command`

Set or remove a single configuration value

#### Parameters

The following parameters are available in the `nextcloud::config_command` defined type.

##### `key`

Data type: `Variant[Boolean, Integer, String]`

The configuration key that should be altered. If prefixed with `DELETE:`
then the key will be completely removed from configuration.

Default value: `$title`

##### `value`

Data type: `Variant[Boolean, Integer, String]`

The configuration value that should be set.

##### `verify_key`

Data type: `Variant[Boolean, Integer, String]`

The configuration key to find out whether it needs to be altered.

##### `verify_value`

Data type: `Variant[Boolean, Integer, String]`

The configuration verify to find out whether it needs to be altered.

### `nextcloud::install::distribution`

Download and extract the distribution archive

#### Parameters

The following parameters are available in the `nextcloud::install::distribution` defined type.

##### `id`

Data type: `Optional[String]`

An optional identifier that can be used to prevent the archive job from
being executed multiple times by remembering its state. This is most useful
to distinguish between an initial install and an update.

Default value: ``undef``

